@@ -28,23 +28,21 @@ def datestr_to_qldate(datestr):
 
 
 def qlSchedule_from_Model(info: FixedRateBond, 
-                        setting: BondSetting, 
                         ql_calendar):
     return qlSchedule(info.issue_date,
                         info.maturity,
-                        ql.Period(ql_frequency[setting.frequency]), 
+                        ql.Period(ql_frequency[info.settings.frequency]), 
                         ql_calendar, 
-                        setting.business_day, 
-                        setting.business_day, 
-                        setting.date_gen, 
-                        setting.is_eom)
+                        info.settings.business_day, 
+                        info.settings.business_day, 
+                        info.settings.date_gen, 
+                        info.settings.is_eom)
 
 
 def structure_from_qlSchedule(bond_info: FixedRateBond,
-                            bond_setting: BondSetting,
                             schedule: ql.QuantLib.Schedule):
     interests = ql.FixedRateLeg(schedule, 
-                            ql_day_count[bond_setting.day_count],
+                            ql_day_count[bond_info.settings.day_count],
                             [bond_info.face_value], 
                             [bond_info.coupon/100],
                             ql.Following)
